=======
History
=======

1.2.0 (2025-05-19)
-------------------
* Updated dependency cellmaps_utils to `0.8.0` from `0.7.0`

* Updated dependency cellmaps_imagedownloader to `0.3.0` from `0.2.1`

* Updated dependency cellmaps_ppidownloader to `0.2.2` from `0.2.1`

* Updated dependency cellmaps_image_embedding to `0.3.2` from `0.3.1`

* Updated dependency cellmaps_ppi_embedding to `0.4.2` from `0.4.1`

* Updated dependency cellmaps_coembedding to `1.2.2` from `1.2.0`

* Updated dependency cellmaps_generate_hierarchy to `0.2.4` from `0.2.3`

* Updated dependency cellmaps_hierarchyeval to `0.2.2` from `0.2.1`

* Updated to PEP 517 compliant build system

1.1.0 (2025-03-20)
------------------

* Unique flag is no longer required to run the pipeline

* Updated versions of packages

1.0.0 (2024-12-09)
------------------

* First release on PyPI.
